# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr
from marqeta_client.models.avs_controls import AvsControls
from marqeta_client.models.strong_customer_authentication_limits import StrongCustomerAuthenticationLimits

class TransactionControls(BaseModel):
    """
    TransactionControls
    """
    accepted_countries_token: Optional[StrictStr] = Field(None, description="50 char max (default = accept_us_only)")
    always_require_pin: Optional[StrictBool] = False
    always_require_icc: Optional[StrictBool] = False
    allow_gpa_auth: Optional[StrictBool] = False
    require_card_not_present_card_security_code: Optional[StrictBool] = False
    allow_mcc_group_authorization_controls: Optional[StrictBool] = False
    allow_first_pin_set_via_financial_transaction: Optional[StrictBool] = False
    ignore_card_suspended_state: Optional[StrictBool] = False
    allow_chip_fallback: Optional[StrictBool] = False
    allow_network_load: Optional[StrictBool] = False
    allow_network_load_card_activation: Optional[StrictBool] = False
    allow_quasi_cash: Optional[StrictBool] = False
    quasi_cash_exempt_merchant_group_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="36 char max")
    enable_partial_auth_approval: Optional[StrictBool] = False
    address_verification: Optional[AvsControls] = None
    notification_language: Optional[StrictStr] = None
    strong_customer_authentication_limits: Optional[StrongCustomerAuthenticationLimits] = None
    quasi_cash_exempt_mids: Optional[StrictStr] = None
    enable_credit_service: Optional[StrictBool] = False
    __properties = ["accepted_countries_token", "always_require_pin", "always_require_icc", "allow_gpa_auth", "require_card_not_present_card_security_code", "allow_mcc_group_authorization_controls", "allow_first_pin_set_via_financial_transaction", "ignore_card_suspended_state", "allow_chip_fallback", "allow_network_load", "allow_network_load_card_activation", "allow_quasi_cash", "quasi_cash_exempt_merchant_group_token", "enable_partial_auth_approval", "address_verification", "notification_language", "strong_customer_authentication_limits", "quasi_cash_exempt_mids", "enable_credit_service"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransactionControls:
        """Create an instance of TransactionControls from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address_verification
        if self.address_verification:
            _dict['address_verification'] = self.address_verification.to_dict()
        # override the default output from pydantic by calling `to_dict()` of strong_customer_authentication_limits
        if self.strong_customer_authentication_limits:
            _dict['strong_customer_authentication_limits'] = self.strong_customer_authentication_limits.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransactionControls:
        """Create an instance of TransactionControls from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TransactionControls.parse_obj(obj)

        _obj = TransactionControls.parse_obj({
            "accepted_countries_token": obj.get("accepted_countries_token"),
            "always_require_pin": obj.get("always_require_pin") if obj.get("always_require_pin") is not None else False,
            "always_require_icc": obj.get("always_require_icc") if obj.get("always_require_icc") is not None else False,
            "allow_gpa_auth": obj.get("allow_gpa_auth") if obj.get("allow_gpa_auth") is not None else False,
            "require_card_not_present_card_security_code": obj.get("require_card_not_present_card_security_code") if obj.get("require_card_not_present_card_security_code") is not None else False,
            "allow_mcc_group_authorization_controls": obj.get("allow_mcc_group_authorization_controls") if obj.get("allow_mcc_group_authorization_controls") is not None else False,
            "allow_first_pin_set_via_financial_transaction": obj.get("allow_first_pin_set_via_financial_transaction") if obj.get("allow_first_pin_set_via_financial_transaction") is not None else False,
            "ignore_card_suspended_state": obj.get("ignore_card_suspended_state") if obj.get("ignore_card_suspended_state") is not None else False,
            "allow_chip_fallback": obj.get("allow_chip_fallback") if obj.get("allow_chip_fallback") is not None else False,
            "allow_network_load": obj.get("allow_network_load") if obj.get("allow_network_load") is not None else False,
            "allow_network_load_card_activation": obj.get("allow_network_load_card_activation") if obj.get("allow_network_load_card_activation") is not None else False,
            "allow_quasi_cash": obj.get("allow_quasi_cash") if obj.get("allow_quasi_cash") is not None else False,
            "quasi_cash_exempt_merchant_group_token": obj.get("quasi_cash_exempt_merchant_group_token"),
            "enable_partial_auth_approval": obj.get("enable_partial_auth_approval") if obj.get("enable_partial_auth_approval") is not None else False,
            "address_verification": AvsControls.from_dict(obj.get("address_verification")) if obj.get("address_verification") is not None else None,
            "notification_language": obj.get("notification_language"),
            "strong_customer_authentication_limits": StrongCustomerAuthenticationLimits.from_dict(obj.get("strong_customer_authentication_limits")) if obj.get("strong_customer_authentication_limits") is not None else None,
            "quasi_cash_exempt_mids": obj.get("quasi_cash_exempt_mids"),
            "enable_credit_service": obj.get("enable_credit_service") if obj.get("enable_credit_service") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from marqeta_client.models.deposit_deposit_response import DepositDepositResponse
from marqeta_client.models.pull_from_card_transfer_response import PullFromCardTransferResponse

class TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue(BaseModel):
    """
    TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue
    """
    tranlog_token: StrictStr = ...
    pull_from_card: Optional[PullFromCardTransferResponse] = None
    direct_deposit: Optional[DepositDepositResponse] = None
    __properties = ["tranlog_token", "pull_from_card", "direct_deposit"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue:
        """Create an instance of TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of pull_from_card
        if self.pull_from_card:
            _dict['pull_from_card'] = self.pull_from_card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of direct_deposit
        if self.direct_deposit:
            _dict['direct_deposit'] = self.direct_deposit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue:
        """Create an instance of TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue.parse_obj(obj)

        _obj = TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue.parse_obj({
            "tranlog_token": obj.get("tranlog_token"),
            "pull_from_card": PullFromCardTransferResponse.from_dict(obj.get("pull_from_card")) if obj.get("pull_from_card") is not None else None,
            "direct_deposit": DepositDepositResponse.from_dict(obj.get("direct_deposit")) if obj.get("direct_deposit") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr

class DisputeTransactionRequest(BaseModel):
    """
    DisputeTransactionRequest
    """
    token: StrictStr = ...
    pan: StrictStr = ...
    reference_transaction_token: StrictStr = ...
    reason: StrictStr = ...
    cash_amount: Optional[Union[StrictFloat, StrictInt]] = None
    pending_amount: Optional[Union[StrictFloat, StrictInt]] = None
    include_acquirer_fees: Optional[StrictBool] = None
    case_management_identifier: Optional[StrictStr] = None
    __properties = ["token", "pan", "reference_transaction_token", "reason", "cash_amount", "pending_amount", "include_acquirer_fees", "case_management_identifier"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DisputeTransactionRequest:
        """Create an instance of DisputeTransactionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DisputeTransactionRequest:
        """Create an instance of DisputeTransactionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DisputeTransactionRequest.parse_obj(obj)

        _obj = DisputeTransactionRequest.parse_obj({
            "token": obj.get("token"),
            "pan": obj.get("pan"),
            "reference_transaction_token": obj.get("reference_transaction_token"),
            "reason": obj.get("reason"),
            "cash_amount": obj.get("cash_amount"),
            "pending_amount": obj.get("pending_amount"),
            "include_acquirer_fees": obj.get("include_acquirer_fees"),
            "case_management_identifier": obj.get("case_management_identifier")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator
from marqeta_client.models.pre_kyc_controls import PreKycControls

class AccountHolderGroupConfig(BaseModel):
    """
    AccountHolderGroupConfig
    """
    kyc_required: Optional[StrictStr] = None
    is_reloadable: Optional[StrictBool] = False
    real_time_fee_group_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    pre_kyc_controls: Optional[PreKycControls] = None
    __properties = ["kyc_required", "is_reloadable", "real_time_fee_group_token", "pre_kyc_controls"]

    @validator('kyc_required')
    def kyc_required_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ALWAYS', 'CONDITIONAL', 'NEVER'):
            raise ValueError("must be one of enum values ('ALWAYS', 'CONDITIONAL', 'NEVER')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccountHolderGroupConfig:
        """Create an instance of AccountHolderGroupConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of pre_kyc_controls
        if self.pre_kyc_controls:
            _dict['pre_kyc_controls'] = self.pre_kyc_controls.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccountHolderGroupConfig:
        """Create an instance of AccountHolderGroupConfig from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AccountHolderGroupConfig.parse_obj(obj)

        _obj = AccountHolderGroupConfig.parse_obj({
            "kyc_required": obj.get("kyc_required"),
            "is_reloadable": obj.get("is_reloadable") if obj.get("is_reloadable") is not None else False,
            "real_time_fee_group_token": obj.get("real_time_fee_group_token"),
            "pre_kyc_controls": PreKycControls.from_dict(obj.get("pre_kyc_controls")) if obj.get("pre_kyc_controls") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, StrictBool, StrictStr
from marqeta_client.models.internal_card import InternalCard
from marqeta_client.models.internal_card_product import InternalCardProduct
from marqeta_client.models.internal_transaction_data_model import InternalTransactionDataModel
from marqeta_client.models.internal_user import InternalUser

class VelocityControlCheckRequest(BaseModel):
    """
    VelocityControlCheckRequest
    """
    card_product: InternalCardProduct = ...
    transaction: InternalTransactionDataModel = ...
    card_holder: InternalUser = ...
    card: Optional[InternalCard] = None
    context: Optional[Dict[str, StrictStr]] = None
    write_cache: Optional[StrictBool] = None
    debug: Optional[StrictBool] = None
    __properties = ["card_product", "transaction", "card_holder", "card", "context", "write_cache", "debug"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VelocityControlCheckRequest:
        """Create an instance of VelocityControlCheckRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card_product
        if self.card_product:
            _dict['card_product'] = self.card_product.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_holder
        if self.card_holder:
            _dict['card_holder'] = self.card_holder.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VelocityControlCheckRequest:
        """Create an instance of VelocityControlCheckRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return VelocityControlCheckRequest.parse_obj(obj)

        _obj = VelocityControlCheckRequest.parse_obj({
            "card_product": InternalCardProduct.from_dict(obj.get("card_product")) if obj.get("card_product") is not None else None,
            "transaction": InternalTransactionDataModel.from_dict(obj.get("transaction")) if obj.get("transaction") is not None else None,
            "card_holder": InternalUser.from_dict(obj.get("card_holder")) if obj.get("card_holder") is not None else None,
            "card": InternalCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "context": obj.get("context"),
            "write_cache": obj.get("write_cache"),
            "debug": obj.get("debug")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conlist
from marqeta_client.models.health_check_result import HealthCheckResult

class PingResponseExtended(BaseModel):
    """
    PingResponseExtended
    """
    success: Optional[StrictBool] = None
    version: Optional[StrictStr] = None
    revision: Optional[StrictStr] = None
    timestamp: Optional[StrictStr] = None
    env: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    system_components: Optional[conlist(HealthCheckResult, unique_items=True)] = None
    __properties = ["success", "version", "revision", "timestamp", "env", "id", "system_components"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PingResponseExtended:
        """Create an instance of PingResponseExtended from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in system_components (list)
        _items = []
        if self.system_components:
            for _item in self.system_components:
                if _item:
                    _items.append(_item.to_dict())
            _dict['system_components'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PingResponseExtended:
        """Create an instance of PingResponseExtended from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PingResponseExtended.parse_obj(obj)

        _obj = PingResponseExtended.parse_obj({
            "success": obj.get("success"),
            "version": obj.get("version"),
            "revision": obj.get("revision"),
            "timestamp": obj.get("timestamp"),
            "env": obj.get("env"),
            "id": obj.get("id"),
            "system_components": [HealthCheckResult.from_dict(_item) for _item in obj.get("system_components")] if obj.get("system_components") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr, constr

class OfferModel(BaseModel):
    """
    OfferModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    active: Optional[StrictBool] = True
    name: constr(strict=True, max_length=255, min_length=0) = ...
    start_date: Optional[datetime] = None
    end_date: Optional[datetime] = None
    purchase_amount: Union[StrictFloat, StrictInt] = ...
    reward_amount: Union[StrictFloat, StrictInt] = ...
    reward_trigger_amount: Optional[Union[StrictFloat, StrictInt]] = None
    campaign_token: constr(strict=True, max_length=36, min_length=1) = ...
    currency_code: StrictStr = ...
    __properties = ["token", "active", "name", "start_date", "end_date", "purchase_amount", "reward_amount", "reward_trigger_amount", "campaign_token", "currency_code"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OfferModel:
        """Create an instance of OfferModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OfferModel:
        """Create an instance of OfferModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return OfferModel.parse_obj(obj)

        _obj = OfferModel.parse_obj({
            "token": obj.get("token"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "name": obj.get("name"),
            "start_date": obj.get("start_date"),
            "end_date": obj.get("end_date"),
            "purchase_amount": obj.get("purchase_amount"),
            "reward_amount": obj.get("reward_amount"),
            "reward_trigger_amount": obj.get("reward_trigger_amount"),
            "campaign_token": obj.get("campaign_token"),
            "currency_code": obj.get("currency_code")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class InternalAddressVerificationRequest(BaseModel):
    """
    InternalAddressVerificationRequest
    """
    compressed: Optional[StrictBool] = None
    address: Optional[StrictStr] = Field(None, description="cardholder address")
    city: Optional[StrictStr] = Field(None, description="cardholder city")
    state: Optional[StrictStr] = Field(None, description="cardholder state")
    country: Optional[StrictStr] = Field(None, description="cardholder country")
    postalcode: Optional[StrictStr] = Field(None, description="cardholder postalcode")
    is_compressed: Optional[StrictBool] = None
    cardholder_name: Optional[StrictStr] = None
    config_provider_type: Optional[StrictStr] = None
    __properties = ["compressed", "address", "city", "state", "country", "postalcode", "is_compressed", "cardholder_name", "config_provider_type"]

    @validator('config_provider_type')
    def config_provider_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('AUTH', 'DWT', 'AV'):
            raise ValueError("must be one of enum values ('AUTH', 'DWT', 'AV')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalAddressVerificationRequest:
        """Create an instance of InternalAddressVerificationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalAddressVerificationRequest:
        """Create an instance of InternalAddressVerificationRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalAddressVerificationRequest.parse_obj(obj)

        _obj = InternalAddressVerificationRequest.parse_obj({
            "compressed": obj.get("compressed"),
            "address": obj.get("address"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "country": obj.get("country"),
            "postalcode": obj.get("postalcode"),
            "is_compressed": obj.get("is_compressed"),
            "cardholder_name": obj.get("cardholder_name"),
            "config_provider_type": obj.get("config_provider_type")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr, validator

class AchPartnerRequestModel(BaseModel):
    """
    AchPartnerRequestModel
    """
    idempotent_hash: Optional[StrictStr] = Field(None, alias="idempotentHash")
    token: Optional[StrictStr] = None
    partner_account_link_reference_token: StrictStr = ...
    partner: StrictStr = ...
    user_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'business_token' is null")
    business_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'user_token' is null")
    is_default_account: Optional[StrictBool] = False
    __properties = ["idempotentHash", "token", "partner_account_link_reference_token", "partner", "user_token", "business_token", "is_default_account"]

    @validator('partner')
    def partner_validate_enum(cls, v):
        if v not in ('PLAID'):
            raise ValueError("must be one of enum values ('PLAID')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AchPartnerRequestModel:
        """Create an instance of AchPartnerRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AchPartnerRequestModel:
        """Create an instance of AchPartnerRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AchPartnerRequestModel.parse_obj(obj)

        _obj = AchPartnerRequestModel.parse_obj({
            "idempotent_hash": obj.get("idempotentHash"),
            "token": obj.get("token"),
            "partner_account_link_reference_token": obj.get("partner_account_link_reference_token"),
            "partner": obj.get("partner"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "is_default_account": obj.get("is_default_account") if obj.get("is_default_account") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist

class BulkRequestModel(BaseModel):
    """
    BulkRequestModel
    """
    user_tokens: Optional[conlist(StrictStr, max_items=500, min_items=1, unique_items=True)] = None
    business_tokens: Optional[conlist(StrictStr, max_items=500, min_items=1, unique_items=True)] = None
    card_tokens: Optional[conlist(StrictStr, max_items=500, min_items=1, unique_items=True)] = None
    kyc_tokens: Optional[conlist(StrictStr, max_items=500, min_items=1, unique_items=True)] = None
    dda_tokens: Optional[conlist(StrictStr, max_items=500, min_items=1, unique_items=True)] = None
    deposit_accounts: Optional[conlist(StrictStr, max_items=500, min_items=1, unique_items=True)] = None
    __properties = ["user_tokens", "business_tokens", "card_tokens", "kyc_tokens", "dda_tokens", "deposit_accounts"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BulkRequestModel:
        """Create an instance of BulkRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BulkRequestModel:
        """Create an instance of BulkRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BulkRequestModel.parse_obj(obj)

        _obj = BulkRequestModel.parse_obj({
            "user_tokens": obj.get("user_tokens"),
            "business_tokens": obj.get("business_tokens"),
            "card_tokens": obj.get("card_tokens"),
            "kyc_tokens": obj.get("kyc_tokens"),
            "dda_tokens": obj.get("dda_tokens"),
            "deposit_accounts": obj.get("deposit_accounts")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.web_push_provisioning_apple_pay_jws_model import WebPushProvisioningApplePayJWSModel

class WebPushProvisioningApplePayJWTResponse(BaseModel):
    """
    WebPushProvisioningApplePayJWTResponse
    """
    jws: WebPushProvisioningApplePayJWSModel = ...
    state: StrictStr = Field(..., description="Unique state associated with the token. MQ will return a UUID here.")
    __properties = ["jws", "state"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebPushProvisioningApplePayJWTResponse:
        """Create an instance of WebPushProvisioningApplePayJWTResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of jws
        if self.jws:
            _dict['jws'] = self.jws.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebPushProvisioningApplePayJWTResponse:
        """Create an instance of WebPushProvisioningApplePayJWTResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return WebPushProvisioningApplePayJWTResponse.parse_obj(obj)

        _obj = WebPushProvisioningApplePayJWTResponse.parse_obj({
            "jws": WebPushProvisioningApplePayJWSModel.from_dict(obj.get("jws")) if obj.get("jws") is not None else None,
            "state": obj.get("state")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist, constr, validator

class DigitalWalletTokenWalletProvider(BaseModel):
    """
    DigitalWalletTokenWalletProvider
    """
    wallet_provider_cardholder_wallet_account_id: Optional[constr(strict=True, max_length=100, min_length=0)] = None
    wallet_provider_risk_assessment: Optional[StrictStr] = None
    wallet_provider_risk_assessment_version: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    wallet_provider_device_score: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    wallet_provider_account_score: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    wallet_provider_pan_source: Optional[StrictStr] = None
    wallet_provider_reason_code: Optional[StrictStr] = None
    recommendation_reasons: Optional[conlist(StrictStr)] = None
    cardholder_wallet_account_email: Optional[StrictStr] = None
    __properties = ["wallet_provider_cardholder_wallet_account_id", "wallet_provider_risk_assessment", "wallet_provider_risk_assessment_version", "wallet_provider_device_score", "wallet_provider_account_score", "wallet_provider_pan_source", "wallet_provider_reason_code", "recommendation_reasons", "cardholder_wallet_account_email"]

    @validator('wallet_provider_risk_assessment')
    def wallet_provider_risk_assessment_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('DECISION_GREEN', 'DECISION_YELLOW', 'DECISION_RED'):
            raise ValueError("must be one of enum values ('DECISION_GREEN', 'DECISION_YELLOW', 'DECISION_RED')")
        return v

    @validator('wallet_provider_pan_source')
    def wallet_provider_pan_source_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ON_FILE', 'KEY_ENTERED', 'MOBILE_BANKING_APP'):
            raise ValueError("must be one of enum values ('ON_FILE', 'KEY_ENTERED', 'MOBILE_BANKING_APP')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletTokenWalletProvider:
        """Create an instance of DigitalWalletTokenWalletProvider from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletTokenWalletProvider:
        """Create an instance of DigitalWalletTokenWalletProvider from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletTokenWalletProvider.parse_obj(obj)

        _obj = DigitalWalletTokenWalletProvider.parse_obj({
            "wallet_provider_cardholder_wallet_account_id": obj.get("wallet_provider_cardholder_wallet_account_id"),
            "wallet_provider_risk_assessment": obj.get("wallet_provider_risk_assessment"),
            "wallet_provider_risk_assessment_version": obj.get("wallet_provider_risk_assessment_version"),
            "wallet_provider_device_score": obj.get("wallet_provider_device_score"),
            "wallet_provider_account_score": obj.get("wallet_provider_account_score"),
            "wallet_provider_pan_source": obj.get("wallet_provider_pan_source"),
            "wallet_provider_reason_code": obj.get("wallet_provider_reason_code"),
            "recommendation_reasons": obj.get("recommendation_reasons"),
            "cardholder_wallet_account_email": obj.get("cardholder_wallet_account_email")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.taba_pay_accounts import TabaPayAccounts
from marqeta_client.models.tabapay_soft_descriptor import TabapaySoftDescriptor

class TabaPayPayoutRequest(BaseModel):
    """
    TabaPayPayoutRequest
    """
    entity: Optional[TabaPayPayoutRequest] = None
    tags: Optional[Dict[str, StrictStr]] = None
    currency: Optional[StrictStr] = None
    amount: Optional[StrictStr] = None
    reference_id: Optional[StrictStr] = Field(None, alias="referenceID")
    accounts: Optional[TabaPayAccounts] = None
    memo: Optional[StrictStr] = None
    timeout: Optional[StrictStr] = None
    soft_descriptor: Optional[TabapaySoftDescriptor] = Field(None, alias="softDescriptor")
    type: Optional[StrictStr] = None
    __properties = ["entity", "tags", "currency", "amount", "referenceID", "accounts", "memo", "timeout", "softDescriptor", "type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TabaPayPayoutRequest:
        """Create an instance of TabaPayPayoutRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "type",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of entity
        if self.entity:
            _dict['entity'] = self.entity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of accounts
        if self.accounts:
            _dict['accounts'] = self.accounts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of soft_descriptor
        if self.soft_descriptor:
            _dict['softDescriptor'] = self.soft_descriptor.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TabaPayPayoutRequest:
        """Create an instance of TabaPayPayoutRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TabaPayPayoutRequest.parse_obj(obj)

        _obj = TabaPayPayoutRequest.parse_obj({
            "entity": TabaPayPayoutRequest.from_dict(obj.get("entity")) if obj.get("entity") is not None else None,
            "tags": obj.get("tags"),
            "currency": obj.get("currency"),
            "amount": obj.get("amount"),
            "reference_id": obj.get("referenceID"),
            "accounts": TabaPayAccounts.from_dict(obj.get("accounts")) if obj.get("accounts") is not None else None,
            "memo": obj.get("memo"),
            "timeout": obj.get("timeout"),
            "soft_descriptor": TabapaySoftDescriptor.from_dict(obj.get("softDescriptor")) if obj.get("softDescriptor") is not None else None,
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr

class StrongCustomerAuthenticationLimits(BaseModel):
    """
    StrongCustomerAuthenticationLimits
    """
    sca_contactless_transaction_limit: Optional[Union[StrictFloat, StrictInt]] = None
    sca_contactless_cumulative_amount_limit: Optional[Union[StrictFloat, StrictInt]] = None
    sca_contactless_transactions_count_limit: Optional[StrictInt] = None
    sca_contactless_transactions_currency: Optional[StrictStr] = None
    sca_lvp_transaction_limit: Optional[Union[StrictFloat, StrictInt]] = None
    sca_lvp_cumulative_amount_limit: Optional[Union[StrictFloat, StrictInt]] = None
    sca_lvp_transactions_count_limit: Optional[StrictInt] = None
    sca_lvp_transactions_currency: Optional[StrictStr] = None
    sca_tra_exemption_amount_limit: Optional[Union[StrictFloat, StrictInt]] = None
    __properties = ["sca_contactless_transaction_limit", "sca_contactless_cumulative_amount_limit", "sca_contactless_transactions_count_limit", "sca_contactless_transactions_currency", "sca_lvp_transaction_limit", "sca_lvp_cumulative_amount_limit", "sca_lvp_transactions_count_limit", "sca_lvp_transactions_currency", "sca_tra_exemption_amount_limit"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> StrongCustomerAuthenticationLimits:
        """Create an instance of StrongCustomerAuthenticationLimits from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "sca_contactless_transaction_limit",
                            "sca_contactless_cumulative_amount_limit",
                            "sca_contactless_transactions_count_limit",
                            "sca_contactless_transactions_currency",
                            "sca_lvp_transaction_limit",
                            "sca_lvp_cumulative_amount_limit",
                            "sca_lvp_transactions_count_limit",
                            "sca_lvp_transactions_currency",
                            "sca_tra_exemption_amount_limit",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> StrongCustomerAuthenticationLimits:
        """Create an instance of StrongCustomerAuthenticationLimits from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return StrongCustomerAuthenticationLimits.parse_obj(obj)

        _obj = StrongCustomerAuthenticationLimits.parse_obj({
            "sca_contactless_transaction_limit": obj.get("sca_contactless_transaction_limit"),
            "sca_contactless_cumulative_amount_limit": obj.get("sca_contactless_cumulative_amount_limit"),
            "sca_contactless_transactions_count_limit": obj.get("sca_contactless_transactions_count_limit"),
            "sca_contactless_transactions_currency": obj.get("sca_contactless_transactions_currency"),
            "sca_lvp_transaction_limit": obj.get("sca_lvp_transaction_limit"),
            "sca_lvp_cumulative_amount_limit": obj.get("sca_lvp_cumulative_amount_limit"),
            "sca_lvp_transactions_count_limit": obj.get("sca_lvp_transactions_count_limit"),
            "sca_lvp_transactions_currency": obj.get("sca_lvp_transactions_currency"),
            "sca_tra_exemption_amount_limit": obj.get("sca_tra_exemption_amount_limit")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, constr, validator
from marqeta_client.models.identification_request_model import IdentificationRequestModel

class CardHolderModel(BaseModel):
    """
    CardHolderModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    active: Optional[StrictBool] = True
    notes: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    ip_address: Optional[constr(strict=True, max_length=39, min_length=0)] = None
    password: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    phone: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    metadata: Optional[Dict[str, StrictStr]] = None
    account_holder_group_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    identifications: Optional[conlist(IdentificationRequestModel)] = None
    honorific: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    gender: Optional[constr(strict=True, max_length=1, min_length=0)] = None
    first_name: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    middle_name: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    last_name: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    email: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    address1: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    address2: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    city: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    state: Optional[constr(strict=True, max_length=32, min_length=0)] = None
    country: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    birth_date: Optional[StrictStr] = None
    corporate_card_holder: Optional[StrictBool] = False
    ssn: Optional[StrictStr] = None
    passport_number: Optional[constr(strict=True, max_length=40, min_length=0)] = None
    passport_expiration_date: Optional[StrictStr] = None
    id_card_number: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    id_card_expiration_date: Optional[StrictStr] = None
    nationality: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    company: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    parent_token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    uses_parent_account: Optional[StrictBool] = Field(False, description="Default is false")
    postal_code: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    __properties = ["token", "active", "notes", "ip_address", "password", "phone", "metadata", "account_holder_group_token", "identifications", "honorific", "gender", "first_name", "middle_name", "last_name", "email", "address1", "address2", "city", "state", "country", "birth_date", "corporate_card_holder", "ssn", "passport_number", "passport_expiration_date", "id_card_number", "id_card_expiration_date", "nationality", "company", "parent_token", "uses_parent_account", "postal_code"]

    @validator('gender')
    def gender_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('F', 'M'):
            raise ValueError("must be one of enum values ('F', 'M')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardHolderModel:
        """Create an instance of CardHolderModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in identifications (list)
        _items = []
        if self.identifications:
            for _item in self.identifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['identifications'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardHolderModel:
        """Create an instance of CardHolderModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardHolderModel.parse_obj(obj)

        _obj = CardHolderModel.parse_obj({
            "token": obj.get("token"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "notes": obj.get("notes"),
            "ip_address": obj.get("ip_address"),
            "password": obj.get("password"),
            "phone": obj.get("phone"),
            "metadata": obj.get("metadata"),
            "account_holder_group_token": obj.get("account_holder_group_token"),
            "identifications": [IdentificationRequestModel.from_dict(_item) for _item in obj.get("identifications")] if obj.get("identifications") is not None else None,
            "honorific": obj.get("honorific"),
            "gender": obj.get("gender"),
            "first_name": obj.get("first_name"),
            "middle_name": obj.get("middle_name"),
            "last_name": obj.get("last_name"),
            "email": obj.get("email"),
            "address1": obj.get("address1"),
            "address2": obj.get("address2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "country": obj.get("country"),
            "birth_date": obj.get("birth_date"),
            "corporate_card_holder": obj.get("corporate_card_holder") if obj.get("corporate_card_holder") is not None else False,
            "ssn": obj.get("ssn"),
            "passport_number": obj.get("passport_number"),
            "passport_expiration_date": obj.get("passport_expiration_date"),
            "id_card_number": obj.get("id_card_number"),
            "id_card_expiration_date": obj.get("id_card_expiration_date"),
            "nationality": obj.get("nationality"),
            "company": obj.get("company"),
            "parent_token": obj.get("parent_token"),
            "uses_parent_account": obj.get("uses_parent_account") if obj.get("uses_parent_account") is not None else False,
            "postal_code": obj.get("postal_code")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr
from marqeta_client.models.spend_control_association import SpendControlAssociation

class AuthControlExemptMidsResponse(BaseModel):
    """
    AuthControlExemptMidsResponse
    """
    token: Optional[StrictStr] = None
    name: constr(strict=True, max_length=255, min_length=0) = ...
    association: Optional[SpendControlAssociation] = None
    mid: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    merchant_group_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="36 char max")
    start_time: Optional[datetime] = None
    end_time: Optional[datetime] = None
    active: Optional[StrictBool] = False
    created: Optional[datetime] = None
    last_updated: Optional[datetime] = None
    __properties = ["token", "name", "association", "mid", "merchant_group_token", "start_time", "end_time", "active", "created", "last_updated"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuthControlExemptMidsResponse:
        """Create an instance of AuthControlExemptMidsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of association
        if self.association:
            _dict['association'] = self.association.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuthControlExemptMidsResponse:
        """Create an instance of AuthControlExemptMidsResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AuthControlExemptMidsResponse.parse_obj(obj)

        _obj = AuthControlExemptMidsResponse.parse_obj({
            "token": obj.get("token"),
            "name": obj.get("name"),
            "association": SpendControlAssociation.from_dict(obj.get("association")) if obj.get("association") is not None else None,
            "mid": obj.get("mid"),
            "merchant_group_token": obj.get("merchant_group_token"),
            "start_time": obj.get("start_time"),
            "end_time": obj.get("end_time"),
            "active": obj.get("active") if obj.get("active") is not None else False,
            "created": obj.get("created"),
            "last_updated": obj.get("last_updated")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr, conlist, validator
from marqeta_client.models.funding_tranlog import FundingTranlog
from marqeta_client.models.internal_authorization_transaction import InternalAuthorizationTransaction
from marqeta_client.models.velocity_cache import VelocityCache

class InternalTransactionMessage(BaseModel):
    """
    InternalTransactionMessage
    """
    processing_start_time_millis: Optional[StrictInt] = None
    authorization_tranlog: InternalAuthorizationTransaction = ...
    funding_tranlog: Optional[FundingTranlog] = None
    velocity_caches: Optional[conlist(VelocityCache)] = None
    context: Optional[Dict[str, Dict[str, Any]]] = None
    credit_debit_indicator: Optional[StrictStr] = None
    __properties = ["processing_start_time_millis", "authorization_tranlog", "funding_tranlog", "velocity_caches", "context", "credit_debit_indicator"]

    @validator('credit_debit_indicator')
    def credit_debit_indicator_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('CREDIT', 'DEBIT', 'NONE'):
            raise ValueError("must be one of enum values ('CREDIT', 'DEBIT', 'NONE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalTransactionMessage:
        """Create an instance of InternalTransactionMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of authorization_tranlog
        if self.authorization_tranlog:
            _dict['authorization_tranlog'] = self.authorization_tranlog.to_dict()
        # override the default output from pydantic by calling `to_dict()` of funding_tranlog
        if self.funding_tranlog:
            _dict['funding_tranlog'] = self.funding_tranlog.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in velocity_caches (list)
        _items = []
        if self.velocity_caches:
            for _item in self.velocity_caches:
                if _item:
                    _items.append(_item.to_dict())
            _dict['velocity_caches'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalTransactionMessage:
        """Create an instance of InternalTransactionMessage from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalTransactionMessage.parse_obj(obj)

        _obj = InternalTransactionMessage.parse_obj({
            "processing_start_time_millis": obj.get("processing_start_time_millis"),
            "authorization_tranlog": InternalAuthorizationTransaction.from_dict(obj.get("authorization_tranlog")) if obj.get("authorization_tranlog") is not None else None,
            "funding_tranlog": FundingTranlog.from_dict(obj.get("funding_tranlog")) if obj.get("funding_tranlog") is not None else None,
            "velocity_caches": [VelocityCache.from_dict(_item) for _item in obj.get("velocity_caches")] if obj.get("velocity_caches") is not None else None,
            "context": obj.get("context"),
            "credit_debit_indicator": obj.get("credit_debit_indicator")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from marqeta_client.models.card_life_cycle import CardLifeCycle
from marqeta_client.models.card_product_fulfillment import CardProductFulfillment
from marqeta_client.models.clearing_and_settlement import ClearingAndSettlement
from marqeta_client.models.digital_wallet_tokenization import DigitalWalletTokenization
from marqeta_client.models.jit_funding import JitFunding
from marqeta_client.models.poi import Poi
from marqeta_client.models.selective_auth import SelectiveAuth
from marqeta_client.models.special import Special
from marqeta_client.models.transaction_controls import TransactionControls

class CardProductConfig(BaseModel):
    """
    CardProductConfig
    """
    poi: Optional[Poi] = None
    transaction_controls: Optional[TransactionControls] = None
    selective_auth: Optional[SelectiveAuth] = None
    special: Optional[Special] = None
    card_life_cycle: Optional[CardLifeCycle] = None
    clearing_and_settlement: Optional[ClearingAndSettlement] = None
    jit_funding: Optional[JitFunding] = None
    digital_wallet_tokenization: Optional[DigitalWalletTokenization] = None
    fulfillment: Optional[CardProductFulfillment] = None
    __properties = ["poi", "transaction_controls", "selective_auth", "special", "card_life_cycle", "clearing_and_settlement", "jit_funding", "digital_wallet_tokenization", "fulfillment"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardProductConfig:
        """Create an instance of CardProductConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of poi
        if self.poi:
            _dict['poi'] = self.poi.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction_controls
        if self.transaction_controls:
            _dict['transaction_controls'] = self.transaction_controls.to_dict()
        # override the default output from pydantic by calling `to_dict()` of selective_auth
        if self.selective_auth:
            _dict['selective_auth'] = self.selective_auth.to_dict()
        # override the default output from pydantic by calling `to_dict()` of special
        if self.special:
            _dict['special'] = self.special.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_life_cycle
        if self.card_life_cycle:
            _dict['card_life_cycle'] = self.card_life_cycle.to_dict()
        # override the default output from pydantic by calling `to_dict()` of clearing_and_settlement
        if self.clearing_and_settlement:
            _dict['clearing_and_settlement'] = self.clearing_and_settlement.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jit_funding
        if self.jit_funding:
            _dict['jit_funding'] = self.jit_funding.to_dict()
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_tokenization
        if self.digital_wallet_tokenization:
            _dict['digital_wallet_tokenization'] = self.digital_wallet_tokenization.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fulfillment
        if self.fulfillment:
            _dict['fulfillment'] = self.fulfillment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardProductConfig:
        """Create an instance of CardProductConfig from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardProductConfig.parse_obj(obj)

        _obj = CardProductConfig.parse_obj({
            "poi": Poi.from_dict(obj.get("poi")) if obj.get("poi") is not None else None,
            "transaction_controls": TransactionControls.from_dict(obj.get("transaction_controls")) if obj.get("transaction_controls") is not None else None,
            "selective_auth": SelectiveAuth.from_dict(obj.get("selective_auth")) if obj.get("selective_auth") is not None else None,
            "special": Special.from_dict(obj.get("special")) if obj.get("special") is not None else None,
            "card_life_cycle": CardLifeCycle.from_dict(obj.get("card_life_cycle")) if obj.get("card_life_cycle") is not None else None,
            "clearing_and_settlement": ClearingAndSettlement.from_dict(obj.get("clearing_and_settlement")) if obj.get("clearing_and_settlement") is not None else None,
            "jit_funding": JitFunding.from_dict(obj.get("jit_funding")) if obj.get("jit_funding") is not None else None,
            "digital_wallet_tokenization": DigitalWalletTokenization.from_dict(obj.get("digital_wallet_tokenization")) if obj.get("digital_wallet_tokenization") is not None else None,
            "fulfillment": CardProductFulfillment.from_dict(obj.get("fulfillment")) if obj.get("fulfillment") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator
from marqeta_client.models.account_funding_receiver_data import AccountFundingReceiverData

class AccountFundingRequest(BaseModel):
    """
    AccountFundingRequest
    """
    screening_score: Optional[StrictStr] = None
    transaction_type: StrictStr = ...
    receiver_data: AccountFundingReceiverData = ...
    transaction_purpose: Optional[StrictStr] = None
    __properties = ["screening_score", "transaction_type", "receiver_data", "transaction_purpose"]

    @validator('transaction_type')
    def transaction_type_validate_enum(cls, v):
        if v not in ('ACCOUNT_TO_ACCOUNT', 'PERSON_TO_PERSON', 'WALLET_TRANSFER', 'MONEY_TRANSFER_BY_BANK', 'BUSINESS_TO_BUSINESS', 'DISBURSEMENT', 'GOVERNMENT_DISBURSEMENT', 'GAMBLING_PAYOUT', 'LOYALTY', 'MERCHANT_DISBURSEMENT', 'ONLINE_GAMBLING_PAYOUT', 'PENSION_DISBURSEMENT', 'PREPAID_LOADS', 'CARD_BILL_PAYMENT', 'BILL_PAYMENT', 'CASH_CLAIM', 'CASH_IN', 'CASH_OUT', 'MOBILE_AIR_TIME_PAYMENT', 'MONEY_TRANSFER_BY_MERCHANT', 'FACE_TO_FACE_MERCHANT_PAYMENT', 'GOVERNMENT_PAYMENT', 'PAYMENTS_GOODS_SERVICES', 'FUNDS_TRANSFER', 'GENERAL_BUSINESS_TO_BUSINESS_TRANSFER', 'BUSINESS_TO_BUSINESS_TRANSFER', 'CASH_DEPOSIT'):
            raise ValueError("must be one of enum values ('ACCOUNT_TO_ACCOUNT', 'PERSON_TO_PERSON', 'WALLET_TRANSFER', 'MONEY_TRANSFER_BY_BANK', 'BUSINESS_TO_BUSINESS', 'DISBURSEMENT', 'GOVERNMENT_DISBURSEMENT', 'GAMBLING_PAYOUT', 'LOYALTY', 'MERCHANT_DISBURSEMENT', 'ONLINE_GAMBLING_PAYOUT', 'PENSION_DISBURSEMENT', 'PREPAID_LOADS', 'CARD_BILL_PAYMENT', 'BILL_PAYMENT', 'CASH_CLAIM', 'CASH_IN', 'CASH_OUT', 'MOBILE_AIR_TIME_PAYMENT', 'MONEY_TRANSFER_BY_MERCHANT', 'FACE_TO_FACE_MERCHANT_PAYMENT', 'GOVERNMENT_PAYMENT', 'PAYMENTS_GOODS_SERVICES', 'FUNDS_TRANSFER', 'GENERAL_BUSINESS_TO_BUSINESS_TRANSFER', 'BUSINESS_TO_BUSINESS_TRANSFER', 'CASH_DEPOSIT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccountFundingRequest:
        """Create an instance of AccountFundingRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of receiver_data
        if self.receiver_data:
            _dict['receiver_data'] = self.receiver_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccountFundingRequest:
        """Create an instance of AccountFundingRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AccountFundingRequest.parse_obj(obj)

        _obj = AccountFundingRequest.parse_obj({
            "screening_score": obj.get("screening_score"),
            "transaction_type": obj.get("transaction_type"),
            "receiver_data": AccountFundingReceiverData.from_dict(obj.get("receiver_data")) if obj.get("receiver_data") is not None else None,
            "transaction_purpose": obj.get("transaction_purpose")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictStr, confloat, conint, constr, validator

class BankTransferTransitionRequestModel(BaseModel):
    """
    BankTransferTransitionRequestModel
    """
    amount: Optional[Union[confloat(ge=0, strict=True), conint(ge=0, strict=True)]] = None
    token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    bank_transfer_token: constr(strict=True, max_length=36, min_length=0) = ...
    status: StrictStr = ...
    reason: Optional[StrictStr] = None
    channel: StrictStr = ...
    batch_number: Optional[StrictStr] = None
    program_reserve_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    return_code: Optional[StrictStr] = None
    effective_date: Optional[datetime] = None
    reversal_after_45_days: Optional[StrictBool] = None
    __properties = ["amount", "token", "bank_transfer_token", "status", "reason", "channel", "batch_number", "program_reserve_token", "return_code", "effective_date", "reversal_after_45_days"]

    @validator('status')
    def status_validate_enum(cls, v):
        if v not in ('PENDING', 'PROCESSING', 'SUBMITTED', 'RETURNED', 'COMPLETED', 'CANCELLED', 'REVERSAL_PEND', 'REVERSAL_COMP'):
            raise ValueError("must be one of enum values ('PENDING', 'PROCESSING', 'SUBMITTED', 'RETURNED', 'COMPLETED', 'CANCELLED', 'REVERSAL_PEND', 'REVERSAL_COMP')")
        return v

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v not in ('API', 'SYSTEM', 'ADMIN'):
            raise ValueError("must be one of enum values ('API', 'SYSTEM', 'ADMIN')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BankTransferTransitionRequestModel:
        """Create an instance of BankTransferTransitionRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BankTransferTransitionRequestModel:
        """Create an instance of BankTransferTransitionRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BankTransferTransitionRequestModel.parse_obj(obj)

        _obj = BankTransferTransitionRequestModel.parse_obj({
            "amount": obj.get("amount"),
            "token": obj.get("token"),
            "bank_transfer_token": obj.get("bank_transfer_token"),
            "status": obj.get("status"),
            "reason": obj.get("reason"),
            "channel": obj.get("channel"),
            "batch_number": obj.get("batch_number"),
            "program_reserve_token": obj.get("program_reserve_token"),
            "return_code": obj.get("return_code"),
            "effective_date": obj.get("effective_date"),
            "reversal_after_45_days": obj.get("reversal_after_45_days")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from marqeta_client.models.real_time_fee_assessment import RealTimeFeeAssessment

class Fee(BaseModel):
    """
    Fee
    """
    token: StrictStr = Field(..., description="36 char max")
    name: StrictStr = Field(..., description="50 char max")
    amount: Union[StrictFloat, StrictInt] = ...
    tags: Optional[StrictStr] = Field(None, description="255 char max")
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    active: StrictBool = ...
    currency_code: StrictStr = ...
    real_time_assessment: Optional[RealTimeFeeAssessment] = None
    __properties = ["token", "name", "amount", "tags", "created_time", "last_modified_time", "active", "currency_code", "real_time_assessment"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Fee:
        """Create an instance of Fee from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of real_time_assessment
        if self.real_time_assessment:
            _dict['real_time_assessment'] = self.real_time_assessment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Fee:
        """Create an instance of Fee from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Fee.parse_obj(obj)

        _obj = Fee.parse_obj({
            "token": obj.get("token"),
            "name": obj.get("name"),
            "amount": obj.get("amount"),
            "tags": obj.get("tags"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "active": obj.get("active") if obj.get("active") is not None else False,
            "currency_code": obj.get("currency_code"),
            "real_time_assessment": RealTimeFeeAssessment.from_dict(obj.get("real_time_assessment")) if obj.get("real_time_assessment") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator

class IdentificationResponseModel(BaseModel):
    """
    IdentificationResponseModel
    """
    type: Optional[StrictStr] = None
    value: Optional[StrictStr] = None
    expiration_date: Optional[StrictStr] = None
    __properties = ["type", "value", "expiration_date"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('SSN', 'TIN', 'SIN', 'NIN', 'PASSPORT_NUMBER', 'DRIVERS_LICENSE', 'BUSINESS_NUMBER', 'BUSINESS_TAX_ID', 'TAXPAYER_REFERENCE'):
            raise ValueError("must be one of enum values ('SSN', 'TIN', 'SIN', 'NIN', 'PASSPORT_NUMBER', 'DRIVERS_LICENSE', 'BUSINESS_NUMBER', 'BUSINESS_TAX_ID', 'TAXPAYER_REFERENCE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IdentificationResponseModel:
        """Create an instance of IdentificationResponseModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "type",
                            "value",
                            "expiration_date",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IdentificationResponseModel:
        """Create an instance of IdentificationResponseModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return IdentificationResponseModel.parse_obj(obj)

        _obj = IdentificationResponseModel.parse_obj({
            "type": obj.get("type"),
            "value": obj.get("value"),
            "expiration_date": obj.get("expiration_date")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, constr, validator

class ChargebackTransitionResponse(BaseModel):
    """
    ChargebackTransitionResponse
    """
    token: constr(strict=True, max_length=36, min_length=0) = ...
    state: StrictStr = ...
    previous_state: StrictStr = ...
    channel: StrictStr = ...
    chargeback_token: constr(strict=True, max_length=36, min_length=1) = ...
    reason: Optional[constr(strict=True, max_length=1024, min_length=0)] = None
    transaction_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    type: StrictStr = ...
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    __properties = ["token", "state", "previous_state", "channel", "chargeback_token", "reason", "transaction_token", "created_time", "last_modified_time", "type", "amount"]

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('INITIATED', 'REPRESENTMENT', 'PREARBITRATION', 'ARBITRATION', 'CASE_WON', 'CASE_LOST', 'NETWORK_REJECTED', 'WITHDRAWN', 'WRITTEN_OFF_ISSUER', 'WRITTEN_OFF_PROGRAM'):
            raise ValueError("must be one of enum values ('INITIATED', 'REPRESENTMENT', 'PREARBITRATION', 'ARBITRATION', 'CASE_WON', 'CASE_LOST', 'NETWORK_REJECTED', 'WITHDRAWN', 'WRITTEN_OFF_ISSUER', 'WRITTEN_OFF_PROGRAM')")
        return v

    @validator('previous_state')
    def previous_state_validate_enum(cls, v):
        if v not in ('INITIATED', 'REPRESENTMENT', 'PREARBITRATION', 'ARBITRATION', 'CASE_WON', 'CASE_LOST', 'NETWORK_REJECTED', 'WITHDRAWN'):
            raise ValueError("must be one of enum values ('INITIATED', 'REPRESENTMENT', 'PREARBITRATION', 'ARBITRATION', 'CASE_WON', 'CASE_LOST', 'NETWORK_REJECTED', 'WITHDRAWN')")
        return v

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v not in ('GATEWAY', 'GATEWAY_AUTOMATED', 'ISSUER', 'ISSUER_AUTOMATED'):
            raise ValueError("must be one of enum values ('GATEWAY', 'GATEWAY_AUTOMATED', 'ISSUER', 'ISSUER_AUTOMATED')")
        return v

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('initiated', 'representment', 'prearbitration', 'arbitration', 'case.won', 'case.lost', 'network.rejected', 'written.off.issuer', 'written.off.program'):
            raise ValueError("must be one of enum values ('initiated', 'representment', 'prearbitration', 'arbitration', 'case.won', 'case.lost', 'network.rejected', 'written.off.issuer', 'written.off.program')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChargebackTransitionResponse:
        """Create an instance of ChargebackTransitionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChargebackTransitionResponse:
        """Create an instance of ChargebackTransitionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ChargebackTransitionResponse.parse_obj(obj)

        _obj = ChargebackTransitionResponse.parse_obj({
            "token": obj.get("token"),
            "state": obj.get("state"),
            "previous_state": obj.get("previous_state"),
            "channel": obj.get("channel"),
            "chargeback_token": obj.get("chargeback_token"),
            "reason": obj.get("reason"),
            "transaction_token": obj.get("transaction_token"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "type": obj.get("type"),
            "amount": obj.get("amount")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, validator
from marqeta_client.models.internal_address_verification_request import InternalAddressVerificationRequest

class Transaction(BaseModel):
    """
    Transaction
    """
    international: Optional[StrictBool] = None
    address_verification: Optional[InternalAddressVerificationRequest] = None
    is_international: Optional[StrictBool] = None
    network: StrictStr = ...
    currency: Optional[StrictStr] = None
    issuer_country: Optional[StrictStr] = None
    __properties = ["international", "address_verification", "is_international", "network", "currency", "issuer_country"]

    @validator('network')
    def network_validate_enum(cls, v):
        if v not in ('MASTERCARD', 'DISCOVER', 'PULSE', 'VISA'):
            raise ValueError("must be one of enum values ('MASTERCARD', 'DISCOVER', 'PULSE', 'VISA')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Transaction:
        """Create an instance of Transaction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address_verification
        if self.address_verification:
            _dict['address_verification'] = self.address_verification.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Transaction:
        """Create an instance of Transaction from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Transaction.parse_obj(obj)

        _obj = Transaction.parse_obj({
            "international": obj.get("international"),
            "address_verification": InternalAddressVerificationRequest.from_dict(obj.get("address_verification")) if obj.get("address_verification") is not None else None,
            "is_international": obj.get("is_international"),
            "network": obj.get("network"),
            "currency": obj.get("currency"),
            "issuer_country": obj.get("issuer_country")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.commando_mode_enables import CommandoModeEnables
from marqeta_client.models.commando_mode_nested_transition import CommandoModeNestedTransition
from marqeta_client.models.real_time_standin_criteria import RealTimeStandinCriteria

class CommandoModeResponse(BaseModel):
    """
    CommandoModeResponse
    """
    token: Optional[StrictStr] = None
    program_gateway_funding_source_token: Optional[StrictStr] = None
    current_state: Optional[CommandoModeNestedTransition] = None
    commando_mode_enables: Optional[CommandoModeEnables] = None
    real_time_standin_criteria: Optional[RealTimeStandinCriteria] = None
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    __properties = ["token", "program_gateway_funding_source_token", "current_state", "commando_mode_enables", "real_time_standin_criteria", "created_time", "last_modified_time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CommandoModeResponse:
        """Create an instance of CommandoModeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of current_state
        if self.current_state:
            _dict['current_state'] = self.current_state.to_dict()
        # override the default output from pydantic by calling `to_dict()` of commando_mode_enables
        if self.commando_mode_enables:
            _dict['commando_mode_enables'] = self.commando_mode_enables.to_dict()
        # override the default output from pydantic by calling `to_dict()` of real_time_standin_criteria
        if self.real_time_standin_criteria:
            _dict['real_time_standin_criteria'] = self.real_time_standin_criteria.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CommandoModeResponse:
        """Create an instance of CommandoModeResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CommandoModeResponse.parse_obj(obj)

        _obj = CommandoModeResponse.parse_obj({
            "token": obj.get("token"),
            "program_gateway_funding_source_token": obj.get("program_gateway_funding_source_token"),
            "current_state": CommandoModeNestedTransition.from_dict(obj.get("current_state")) if obj.get("current_state") is not None else None,
            "commando_mode_enables": CommandoModeEnables.from_dict(obj.get("commando_mode_enables")) if obj.get("commando_mode_enables") is not None else None,
            "real_time_standin_criteria": RealTimeStandinCriteria.from_dict(obj.get("real_time_standin_criteria")) if obj.get("real_time_standin_criteria") is not None else None,
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator

class CardholderNoteResponseModel(BaseModel):
    """
    CardholderNoteResponseModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    description: StrictStr = ...
    created_by: constr(strict=True, max_length=255, min_length=0) = ...
    created_by_user_role: Optional[StrictStr] = None
    private: Optional[StrictBool] = False
    created_time: Optional[datetime] = None
    last_modified_time: Optional[datetime] = None
    __properties = ["token", "description", "created_by", "created_by_user_role", "private", "created_time", "last_modified_time"]

    @validator('created_by_user_role')
    def created_by_user_role_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('USER', 'ADMIN', 'BANK_USER', 'BANK_ADMIN', 'MARQETA_PD', 'MARQETA_ADMIN'):
            raise ValueError("must be one of enum values ('USER', 'ADMIN', 'BANK_USER', 'BANK_ADMIN', 'MARQETA_PD', 'MARQETA_ADMIN')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardholderNoteResponseModel:
        """Create an instance of CardholderNoteResponseModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardholderNoteResponseModel:
        """Create an instance of CardholderNoteResponseModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardholderNoteResponseModel.parse_obj(obj)

        _obj = CardholderNoteResponseModel.parse_obj({
            "token": obj.get("token"),
            "description": obj.get("description"),
            "created_by": obj.get("created_by"),
            "created_by_user_role": obj.get("created_by_user_role"),
            "private": obj.get("private") if obj.get("private") is not None else False,
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from marqeta_client.models.gateway_response import GatewayResponse

class Gatewaylog(BaseModel):
    """
    Gatewaylog
    """
    id: Optional[StrictInt] = None
    trace_number: Optional[StrictInt] = Field(None, alias="traceNumber")
    payment_type_code: Optional[StrictStr] = Field(None, alias="paymentTypeCode")
    ach_transaction_type: Optional[StrictStr] = Field(None, alias="achTransactionType")
    memo: Optional[StrictStr] = None
    gateway_version: Optional[StrictStr] = Field(None, alias="gatewayVersion")
    gateway_response: Optional[GatewayResponse] = Field(None, alias="gatewayResponse")
    timed_out: Optional[StrictBool] = Field(None, alias="timedOut")
    deal_id: Optional[StrictInt] = Field(None, alias="deal_Id")
    order_id: Optional[StrictStr] = Field(None, alias="order_Id")
    request_method: Optional[StrictStr] = None
    response_code: Optional[StrictStr] = None
    response_subcode: Optional[StrictStr] = None
    response_reasoncode: Optional[StrictStr] = None
    response_message: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    fraud_avs: Optional[StrictStr] = None
    fraud_auth: Optional[StrictStr] = None
    fraud_cvv: Optional[StrictStr] = None
    gateway_transaction_id: Optional[StrictStr] = Field(None, alias="gateway_transactionId")
    original_gateway: Optional[Gatewaylog] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    duplicate: Optional[StrictStr] = None
    post_date: Optional[datetime] = None
    response_time: Optional[datetime] = None
    api_duration: Optional[StrictInt] = None
    gateway_duration: Optional[StrictInt] = None
    ach_status: Optional[StrictStr] = None
    created: Optional[datetime] = None
    modified: Optional[datetime] = None
    __properties = ["id", "traceNumber", "paymentTypeCode", "achTransactionType", "memo", "gatewayVersion", "gatewayResponse", "timedOut", "deal_Id", "order_Id", "request_method", "response_code", "response_subcode", "response_reasoncode", "response_message", "status", "fraud_avs", "fraud_auth", "fraud_cvv", "gateway_transactionId", "original_gateway", "amount", "duplicate", "post_date", "response_time", "api_duration", "gateway_duration", "ach_status", "created", "modified"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Gatewaylog:
        """Create an instance of Gatewaylog from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gateway_response
        if self.gateway_response:
            _dict['gatewayResponse'] = self.gateway_response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_gateway
        if self.original_gateway:
            _dict['original_gateway'] = self.original_gateway.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Gatewaylog:
        """Create an instance of Gatewaylog from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Gatewaylog.parse_obj(obj)

        _obj = Gatewaylog.parse_obj({
            "id": obj.get("id"),
            "trace_number": obj.get("traceNumber"),
            "payment_type_code": obj.get("paymentTypeCode"),
            "ach_transaction_type": obj.get("achTransactionType"),
            "memo": obj.get("memo"),
            "gateway_version": obj.get("gatewayVersion"),
            "gateway_response": GatewayResponse.from_dict(obj.get("gatewayResponse")) if obj.get("gatewayResponse") is not None else None,
            "timed_out": obj.get("timedOut"),
            "deal_id": obj.get("deal_Id"),
            "order_id": obj.get("order_Id"),
            "request_method": obj.get("request_method"),
            "response_code": obj.get("response_code"),
            "response_subcode": obj.get("response_subcode"),
            "response_reasoncode": obj.get("response_reasoncode"),
            "response_message": obj.get("response_message"),
            "status": obj.get("status"),
            "fraud_avs": obj.get("fraud_avs"),
            "fraud_auth": obj.get("fraud_auth"),
            "fraud_cvv": obj.get("fraud_cvv"),
            "gateway_transaction_id": obj.get("gateway_transactionId"),
            "original_gateway": Gatewaylog.from_dict(obj.get("original_gateway")) if obj.get("original_gateway") is not None else None,
            "amount": obj.get("amount"),
            "duplicate": obj.get("duplicate"),
            "post_date": obj.get("post_date"),
            "response_time": obj.get("response_time"),
            "api_duration": obj.get("api_duration"),
            "gateway_duration": obj.get("gateway_duration"),
            "ach_status": obj.get("ach_status"),
            "created": obj.get("created"),
            "modified": obj.get("modified")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, constr
from marqeta_client.models.webhook_config_model import WebhookConfigModel

class WebhookRequestModel(BaseModel):
    """
    WebhookRequestModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    name: constr(strict=True, max_length=64, min_length=1) = ...
    active: Optional[StrictBool] = True
    config: WebhookConfigModel = ...
    events: conlist(StrictStr) = Field(..., description="An array of event types")
    __properties = ["token", "name", "active", "config", "events"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebhookRequestModel:
        """Create an instance of WebhookRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebhookRequestModel:
        """Create an instance of WebhookRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return WebhookRequestModel.parse_obj(obj)

        _obj = WebhookRequestModel.parse_obj({
            "token": obj.get("token"),
            "name": obj.get("name"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "config": WebhookConfigModel.from_dict(obj.get("config")) if obj.get("config") is not None else None,
            "events": obj.get("events")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr, conlist
from marqeta_client.models.response import Response
from marqeta_client.models.velocity_cache import VelocityCache
from marqeta_client.models.velocity_control_check_request import VelocityControlCheckRequest

class VelocityControlCheckResponse(BaseModel):
    """
    VelocityControlCheckResponse
    """
    velocity_control_check_request: Optional[VelocityControlCheckRequest] = None
    velocity_check_name: Optional[StrictStr] = None
    balance: Optional[Union[StrictFloat, StrictInt]] = None
    response: Optional[Response] = None
    context: Optional[Dict[str, StrictStr]] = None
    caches: Optional[conlist(VelocityCache)] = None
    __properties = ["velocity_control_check_request", "velocity_check_name", "balance", "response", "context", "caches"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VelocityControlCheckResponse:
        """Create an instance of VelocityControlCheckResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of velocity_control_check_request
        if self.velocity_control_check_request:
            _dict['velocity_control_check_request'] = self.velocity_control_check_request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response
        if self.response:
            _dict['response'] = self.response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in caches (list)
        _items = []
        if self.caches:
            for _item in self.caches:
                if _item:
                    _items.append(_item.to_dict())
            _dict['caches'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VelocityControlCheckResponse:
        """Create an instance of VelocityControlCheckResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return VelocityControlCheckResponse.parse_obj(obj)

        _obj = VelocityControlCheckResponse.parse_obj({
            "velocity_control_check_request": VelocityControlCheckRequest.from_dict(obj.get("velocity_control_check_request")) if obj.get("velocity_control_check_request") is not None else None,
            "velocity_check_name": obj.get("velocity_check_name"),
            "balance": obj.get("balance"),
            "response": Response.from_dict(obj.get("response")) if obj.get("response") is not None else None,
            "context": obj.get("context"),
            "caches": [VelocityCache.from_dict(_item) for _item in obj.get("caches")] if obj.get("caches") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, conlist
from marqeta_client.models.internal_account import InternalAccount

class InternalUser(BaseModel):
    """
    InternalUser
    """
    id: Optional[StrictInt] = None
    token: Optional[StrictStr] = None
    active: Optional[StrictBool] = None
    email: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    uses_parent_account: Optional[StrictBool] = False
    corporate_card_holder: Optional[StrictBool] = False
    user_accounts: Optional[conlist(InternalAccount)] = None
    __properties = ["id", "token", "active", "email", "type", "uses_parent_account", "corporate_card_holder", "user_accounts"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalUser:
        """Create an instance of InternalUser from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in user_accounts (list)
        _items = []
        if self.user_accounts:
            for _item in self.user_accounts:
                if _item:
                    _items.append(_item.to_dict())
            _dict['user_accounts'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalUser:
        """Create an instance of InternalUser from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalUser.parse_obj(obj)

        _obj = InternalUser.parse_obj({
            "id": obj.get("id"),
            "token": obj.get("token"),
            "active": obj.get("active"),
            "email": obj.get("email"),
            "type": obj.get("type"),
            "uses_parent_account": obj.get("uses_parent_account") if obj.get("uses_parent_account") is not None else False,
            "corporate_card_holder": obj.get("corporate_card_holder") if obj.get("corporate_card_holder") is not None else False,
            "user_accounts": [InternalAccount.from_dict(_item) for _item in obj.get("user_accounts")] if obj.get("user_accounts") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class TokenServiceProvider(BaseModel):
    """
    TokenServiceProvider
    """
    token_reference_id: Optional[StrictStr] = None
    pan_reference_id: StrictStr = Field(..., description="50 char max")
    correlation_id: Optional[StrictStr] = None
    token_requestor_id: Optional[StrictStr] = None
    token_requestor_name: Optional[StrictStr] = None
    token_type: Optional[StrictStr] = None
    token_pan: Optional[StrictStr] = None
    token_expiration: Optional[StrictStr] = None
    token_score: Optional[StrictStr] = None
    token_assurance_level: Optional[StrictStr] = None
    token_eligibility_decision: Optional[StrictStr] = None
    __properties = ["token_reference_id", "pan_reference_id", "correlation_id", "token_requestor_id", "token_requestor_name", "token_type", "token_pan", "token_expiration", "token_score", "token_assurance_level", "token_eligibility_decision"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TokenServiceProvider:
        """Create an instance of TokenServiceProvider from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TokenServiceProvider:
        """Create an instance of TokenServiceProvider from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TokenServiceProvider.parse_obj(obj)

        _obj = TokenServiceProvider.parse_obj({
            "token_reference_id": obj.get("token_reference_id"),
            "pan_reference_id": obj.get("pan_reference_id"),
            "correlation_id": obj.get("correlation_id"),
            "token_requestor_id": obj.get("token_requestor_id"),
            "token_requestor_name": obj.get("token_requestor_name"),
            "token_type": obj.get("token_type"),
            "token_pan": obj.get("token_pan"),
            "token_expiration": obj.get("token_expiration"),
            "token_score": obj.get("token_score"),
            "token_assurance_level": obj.get("token_assurance_level"),
            "token_eligibility_decision": obj.get("token_eligibility_decision")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from marqeta_client.models.internal_card import InternalCard
from marqeta_client.models.response import Response

class CardValidationResponse(BaseModel):
    """
    CardValidationResponse
    """
    card: Optional[InternalCard] = None
    response: Optional[Response] = None
    __properties = ["card", "response"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardValidationResponse:
        """Create an instance of CardValidationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response
        if self.response:
            _dict['response'] = self.response.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardValidationResponse:
        """Create an instance of CardValidationResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardValidationResponse.parse_obj(obj)

        _obj = CardValidationResponse.parse_obj({
            "card": InternalCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "response": Response.from_dict(obj.get("response")) if obj.get("response") is not None else None
        })
        return _obj

